package net.wanji.opt.synthesis.controller;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;
import net.wanji.common.framework.rest.JsonViewObject;
import net.wanji.opt.dao.mapper.SynthesisOptimizeLogInfoMapper;
import net.wanji.opt.synthesis.pojo.StrategyControlDataEntity;
import net.wanji.opt.synthesis.pojo.StrategyControlDetailList;
import net.wanji.opt.synthesis.pojo.StrategyControlVO;
import net.wanji.opt.synthesis.pojo.StrategyFactoryEntity;
import net.wanji.opt.synthesis.service.StrategyControlService;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.ws.rs.core.MediaType;

/**
 * @author duanruiming
 * @date 2024/11/03 12:42
 * @description 神思电子获取1.1策略计划基础信息
 */
@Api(value = "StrategyControlController", description = "策略控制")
@RequestMapping("/strategyControl")
@RestController
public class StrategyControlController {

    @Resource
    private StrategyControlService strategyControlService;
    @Resource
    SynthesisOptimizeLogInfoMapper synthesisOptimizeLogInfoMapper;

    @ApiOperation(value = "策略控制信息操作", notes = "策略控制信息操作",
            response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @PostMapping(value = "/strategyInfoOperation",
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = StrategyControlVO.class),
    })
    public JsonViewObject strategyInfoOperation(@RequestBody StrategyControlVO strategyControlVO) throws Exception {
        return strategyControlService.strategyInfoOperation(strategyControlVO);
    }

    @ApiOperation(value = "策略控制信息分页查询", notes = "策略控制信息分页查询",
            response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @PostMapping(value = "/strategyInfoPageList",
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = StrategyControlDataEntity.class),
    })
    public JsonViewObject strategyInfoPageList(@RequestBody StrategyControlDataEntity entity) throws Exception {
        return strategyControlService.strategyInfoPageList(entity);
    }

    @ApiOperation(value = "策略控制查询列表", notes = "策略控制查询列表",
            response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @GetMapping(value = "/crossStrategyInfoList")
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = StrategyControlDataEntity.class),
    })
    public JsonViewObject crossStrategyInfoList(@RequestParam Integer type) throws Exception {
        return strategyControlService.crossStrategyInfoList(type);
    }


    @ApiOperation(value = "路网优化监测", notes = "路网优化监测",
            response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @GetMapping(value = "/crossOptInfoList")
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = StrategyControlDataEntity.class),
    })
    public JsonViewObject crossOptInfoList(@RequestParam Integer type) throws Exception {
        return strategyControlService.crossOptInfoList(type);
    }

    @ApiOperation(value = "策略管理计划详情查询", notes = "策略管理计划详情查询",
            response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @GetMapping(value = "/strategyPlanDetail")
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = StrategyControlDetailList.class),
    })
    public JsonViewObject strategyPlanDetail(@RequestParam String crossId) throws Exception {
        return strategyControlService.strategyPlanDetail(crossId);
    }

    @ApiOperation(value = "策略管理计划详情下发", notes = "策略管理计划详情下发",
            response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @PostMapping(value = "/strategyPush",
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = StrategyControlDetailList.class),
    })
    public JsonViewObject strategyPush(@RequestBody @Validated StrategyControlDetailList list) throws Exception {
        return strategyControlService.strategyPush(list);
    }

    @ApiOperation(value = "策略管理计划保存", notes = "策略管理计划列表查询",
            response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @PostMapping(value = "/strategyPlanSave",
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = StrategyControlDetailList.class),
    })
    public JsonViewObject strategyPlanSave(@RequestBody @Validated StrategyControlDetailList list) throws Exception {
        return strategyControlService.strategyPlanSave(list);
    }

    @ApiOperation(value = "策略库查询列表", notes = "策略库查询列表",
            response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @GetMapping(value = "/strategyFactoryList")
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = StrategyFactoryEntity.class),
    })
    public JsonViewObject strategyFactoryList() throws Exception {
        return strategyControlService.strategyFactoryList();
    }

    @ApiOperation(value = "策略管理计划保存", notes = "策略管理计划列表查询",
            response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @PostMapping(value = "/strategyFactorySave",
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = StrategyFactoryEntity.class),
    })
    public JsonViewObject strategyFactorySave(@RequestBody @Validated StrategyFactoryEntity entity) throws Exception {
        return strategyControlService.strategyFactorySave(entity);
    }


    @ApiOperation(value = "策略管理计划保存", notes = "策略管理计划列表查询",
            response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @PostMapping(value = "/strategyFactoryDel",
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = StrategyFactoryEntity.class),
    })
    public JsonViewObject strategyFactoryDel(@RequestBody Integer id) throws Exception {
        return strategyControlService.strategyFactoryDel(id);
    }
}
